@@ -9,6 +9,21 @@ compile_scss <- function(data, id = NULL) {
 
   has_id <- !is.null(id)
 
+  # Get the vector of fonts and transform to a `font-family` string
+  font_vec <- unique(dt_options_get_value(data = data, option = "table_font_names"))
+  font_family_attr <- as_css_font_family_attr(font_vec = font_vec)
+
+  # Get any additional CSS statements
+  additional_css <- dt_options_get_value(data = data, option = "table_additional_css")
+
+  # Determine if there are any additional CSS statements
+  has_additional_css <- any(nchar(additional_css) > 0)
+
+  # Combine any additional CSS statements and separate with `\n`
+  if (has_additional_css) {
+    table_additional_css <- paste(additional_css, collapse = "\n") %>% paste_right("\n")
+  }
+
   sass::sass(
     list(
       list(element_id = id),
@@ -19,14 +34,14 @@ compile_scss <- function(data, id = NULL) {
         .open = "<<", .close = ">>",
         "
         <<ifelse(has_id, 'html', '.gt_table')>> {
-          font-family: -apple-system, BlinkMacSystemFont, 'Segoe UI', Roboto,
-            Oxygen, Ubuntu, Cantarell, 'Helvetica Neue', 'Fira Sans', 'Droid Sans',
-            Arial, sans-serif;
+          <<font_family_attr>>
         }
 
         <<ifelse(has_id, '##{$element_id} {', '')>>
         @include gt_styles();
         <<ifelse(has_id, '}', '')>>
+
+        <<ifelse(has_additional_css, table_additional_css, '')>>
         ")
     )
   )
