@@ -103,17 +103,20 @@ cols_align <- function(data,
 #' Set the widths of columns
 #'
 #' Manual specifications of column widths can be performed using the
-#' `cols_width()` function. We choose which columns get specific widths (in
-#' pixels, usually by use of the [px()] helper function). Width assignments are
-#' supplied in `...` through two-sided formulas, where the left-hand side
-#' defines the target columns and the right-hand side is a single width value in
-#' pixels.
+#' `cols_width()` function. We choose which columns get specific widths. This
+#' can be in units of pixels (easily set by use of the [px()] helper function),
+#' or, as percentages (where the [pct()] helper function is useful). Width
+#' assignments are supplied in `...` through two-sided formulas, where the
+#' left-hand side defines the target columns and the right-hand side is a single
+#' dimension.
 #'
-#' Normally, column widths are automatically set to span across the width of the
-#' container (both table and container widths can be individually modified with
-#' the `table.width` and `container.width` options within [tab_options()]). When
-#' using `cols_width()` though, the `table.width` option is disregarded in
-#' favor of the pixel values set for each column.
+#' Column widths can be set as absolute or relative values (with px and
+#' percentage values). Those columns not specified are treated as having
+#' variable width. The sizing behavior for column widths depends on the
+#' combination of value types, and, whether a table width has been set (which
+#' could, itself, be expressed as an absolute or relative value). Widths for the
+#' table and its container can be individually modified with the `table.width`
+#' and `container.width` arguments within [tab_options()]).
 #'
 #' @inheritParams cols_align
 #' @param ... Expressions for the assignment of column widths for the table
@@ -200,10 +203,13 @@ cols_width <- function(data,
     cols <- width_item %>% rlang::f_lhs()
 
     columns <-
-      resolve_vars(
-        var_expr = !!cols,
-        data = data
-      ) %>%
+      dt_boxhead_get_vars(data)[
+        resolve_data_vals_idx(
+          var_expr = !!cols,
+          data_tbl = NULL,
+          vals = dt_boxhead_get_vars(data)
+        )
+      ] %>%
       base::setdiff(columns_used)
 
     columns_used <- c(columns_used, columns)
@@ -213,6 +219,9 @@ cols_width <- function(data,
       rlang::f_rhs() %>%
       rlang::eval_tidy()
 
+    # If a bare numeric value is provided, give that the `px` dimension
+    if (is.numeric(width)) width <- paste_right(as.character(width), "px")
+
     for (column in columns) {
       data <- data %>% dt_boxhead_edit(var = column, column_width = list(width))
     }
@@ -229,15 +238,9 @@ cols_width <- function(data,
 
     columns_unset <- (data %>% dt_boxhead_get_vars())[unset_widths]
 
-    warning("Unset column widths found, setting them to `100px`:\n",
-            " * columns: ",
-            str_catalog(columns_unset),
-            ".\n",
-            " * Set any remaining column widths in `cols_width()` with `everything() ~ px(100)`.",
-            call. = FALSE)
-
     for (column in columns_unset) {
-      data <- data %>% dt_boxhead_edit(var = column, column_width = list("100px"))
+
+      data <- data %>% dt_boxhead_edit(var = column, column_width = list(""))
     }
   }
 
