@@ -9,12 +9,32 @@ footnote_mark_to_html <- function(mark) {
 
 styles_to_html <- function(styles) {
 
-  style_list <-
-    lapply(styles, function(x) cell_style_to_html(x)) %>%
-    unname() %>%
-    unlist(recursive = FALSE)
+  vapply(
+    styles,
+    FUN.VALUE = character(1), USE.NAMES = FALSE,
+    FUN = function(x) {
 
-  paste0(names(style_list), ": ", style_list, ";", collapse = " ")
+      if (any(is.null(names(x)))) {
+
+        style <- gsub(":", ": ", x, fixed = TRUE)
+
+      } else if (all(names(x) != "")) {
+
+        x <- cell_style_to_html(x)
+
+        style <-
+          paste0(names(x), ": ", x, ";", collapse = " ") %>%
+          tidy_gsub(";;", ";")
+
+      } else {
+        style <- as.character(x)
+      }
+
+      style
+    }
+  ) %>%
+    paste(collapse = " ") %>%
+    tidy_gsub("\n", " ")
 }
 
 cell_style_to_html <- function(style) {
@@ -67,38 +87,53 @@ get_table_defs <- function(data) {
 
   boxh <- dt_boxhead_get(data = data)
 
-  if (boxh$column_width %>% unlist() %>% length() > 0) {
+  # Get the `table-layout` value, which is set in `_options`
+  table_style <-
+    paste0("table-layout: ", dt_options_get_value(data, option = "table_layout"), ";")
 
-    widths <-
-      boxh %>%
-      dplyr::filter(type == "default") %>%
-      .$column_width %>%
-      unlist()
-
-    # Assumption is that all width values are `px` values
-    total_width <-
-      widths %>%
-      tidy_gsub("px", "") %>%
-      as.numeric() %>%
-      sum(na.rm = TRUE) %>%
-      as.character() %>%
-      paste_right("px")
-
-    table_style <-
-      paste("table-layout: fixed", paste0("width: ", total_width), sep = "; ")
-
-    table_colgroups <-
-      htmltools::tags$colgroup(
-        lapply(widths, function(width) {
-          htmltools::tags$col(style = paste0("width: ", width))
-        })
-      )
-
-  } else {
-    table_style <- NULL
-    table_colgroups <- NULL
+  # In the case that column widths are not set for any columns,
+  # there should not be a `<colgroup>` tag requirement
+  if (boxh$column_width %>% unlist() %>% length() < 1) {
+    return(list(table_style = NULL, table_colgroups = NULL))
   }
 
+  # Get the table's width (which or may not have been set)
+  table_width <- dt_options_get_value(data, option = "table_width")
+
+  widths <-
+    boxh %>%
+    dplyr::filter(type %in% c("default", "stub")) %>%
+    dplyr::arrange(dplyr::desc(type)) %>% # This ensures that the `stub` is first
+    .$column_width %>%
+    unlist()
+
+  # Stop function if all length dimensions (where provided)
+  # don't conform to accepted CSS length definitions
+  validate_css_lengths(widths)
+
+  # If all of the widths are defined as px values for all columns,
+  # then ensure that the width values are strictly respected as
+  # absolute width values (even if a table width has already been set)
+  if (all(grepl("px", widths)) && table_width == "auto") {
+    table_width <- "0px"
+  }
+
+  if (all(grepl("%", widths)) && table_width == "auto") {
+    table_width <- "100%"
+  }
+
+  if (table_width != "auto") {
+    table_style <- paste(table_style, paste0("width: ", table_width), sep = "; ")
+  }
+
+  # Create the `<colgroup>` tag
+  table_colgroups <-
+    htmltools::tags$colgroup(
+      lapply(widths, function(width) {
+        htmltools::tags$col(style = htmltools::css(width = width))
+      })
+    )
+
   list(
     table_style = table_style,
     table_colgroups = table_colgroups
@@ -1093,3 +1128,15 @@ build_row_styles <- function(styles_resolved_row,
 
   row_styles
 }
+
+as_css_font_family_attr <- function(font_vec, value_only = FALSE) {
+
+  fonts_spaces <- grepl(" ", font_vec)
+  font_vec[fonts_spaces] <- paste_between(x = font_vec[fonts_spaces], x_2 = c("'", "'"))
+
+  value <- paste(font_vec, collapse = ", ")
+
+  if (value_only) return(value)
+
+  paste_between(value, x_2 = c("font-family: ", ";"))
+}
